package com.pfc.Actividades.RealidadAumentada;

// Esta clase es utilizada cdo se esta mostrando AR en la camara.

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Point;
import android.location.Location;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import com.pfc.Actividades.R;
import com.pfc.Actividades.InfoFoto;
import com.pfc.Info.GeoNodo;
import com.pfc.Info.Foto;
import com.pfc.Info.Usuario;
import com.pfc.SuperposicionesAR.DibujaRecurso;
import com.pfc.Utilidades.Localizacion;

public class GeonodoAR implements ARNodeDrawingIF{
	
	private static final int PHOTO = 0;
	
	private DibujaRecurso drawn;
	private boolean isloaded = false;
	private GeoNodo geoNode;
	private float distance;
	private float azimuth = 0;
	private Point point = null;
	
	private Activity mActivity;
	private GestorCapa layers;
	
	private Handler mHandler = new Handler(){
		@Override
		public void handleMessage(Message msg) {
			VistaAR activity = (VistaAR) mActivity;
			int num = activity.getResourcesList().indexOf(GeonodoAR.this);
			
			if(Foto.class.isInstance(geoNode)){
				Foto node = (Foto) geoNode;
				layers.refreshPhoto(num, node.getBitmapImageThumb());
			}
		}
	};
	
	private DibujaRecurso.OnBoxChangeListener onBoxChangeListener = new DibujaRecurso.OnBoxChangeListener() {
		
		public void onChange(int left, int top, int right, int bottom) {
			VistaAR activity = (VistaAR) mActivity;
			int num = activity.getResourcesList().indexOf(GeonodoAR.this);
			if(!layers.translateSummaryBox(num, left, top, right, bottom))
				drawn.unregisterBoxListener();
		}
	};
	
	private DibujaRecurso.OnIconClickListener onIconClickListener = new DibujaRecurso.OnIconClickListener() {
		public void onClick(boolean isOpen) {
			setSummaryBox(isOpen);
		}
	};
	
	public GeonodoAR(Activity activity, GestorCapa layers, GeoNodo geoNode) {
		this.mActivity = activity;
		this.geoNode = geoNode;
		this.layers = layers;
		
		point = new Point();
	}

	public GeoNodo getGeoNode(){
		return geoNode;
	}
	
	public DibujaRecurso getDrawn(){
		return drawn;
	}
	
	public Point getPoint(){
		return point;
	}
	
	public boolean isLoaded(){
		return isloaded;
	}
	
	public void setLoaded(boolean isloaded){
		this.isloaded = isloaded;
	}
	
	public void setDrawnValues(float azimuth, float abs_azimuth, float elevation, float distance){
		drawn.setValues(azimuth, elevation, distance);
		this.distance = distance;
		this.azimuth = abs_azimuth;
		
		point.set((int)(Localizacion.distanceLog((double)distance) * 100 * Math.sin(Math.toRadians(abs_azimuth))), 
				(int)(Localizacion.distanceLog((double)distance) * -100 * Math.cos(Math.toRadians(abs_azimuth))));
	}
	
	public float getAzimuth(){
		return azimuth;
	}
	
	public void createDrawn(Context context, String name, Bitmap bitmap){
		this.drawn = new DibujaRecurso(context, name, bitmap);
		this.drawn.setOnIconClickListener(onIconClickListener);
	}
	
	public void bringDrawnToFront(){
		drawn.bringToFront();
	}
	
	public void drawDistance(boolean draw){
		drawn.drawDistance(draw);
	}
	
	public void invalidateDrawn(){
		drawn.invalidate();
	}
	
	public float distanceToResource(float[] source){
		float d;
		
		Location sLocation = new Location ("gps");
		sLocation.setLatitude(source[0]);
		sLocation.setLongitude(source[1]);		
		d = sLocation.distanceTo(geoNode.getLocation());
		
		return d;
	}
	
	public float azimuthToResource(float source[]){
		float azimuth, resource[] = new float[2];
		
		resource[0] = (float) geoNode.getLocation().getLatitude();
		resource[1] = (float) geoNode.getLocation().getLongitude();		
		azimuth = Localizacion.calculateResourceAzimuth(source, resource);		
		return azimuth;
	}
	
	public float rollToResource(float distance){
		float roll;
		
		roll = Localizacion.calculateRoll(distance, (float) geoNode.getLocation().getAltitude());
		return roll;
	}
	
	public void setSummaryBox(boolean setBox){
		if(!setBox){
			drawn.unregisterBoxListener();
			layers.removeSummaryBox();
			return;
		}
		
		drawn.setOnBoxChangeListener(onBoxChangeListener);
		
		String title = "";
		String description = "";
		Bitmap image = null;
		Thread th = null;
		
		OnClickListener clickListener = null;
		if(Foto.class.isInstance(geoNode)){
			final Foto node = (Foto) geoNode;
			title = node.getName();
			description = node.getDescription();
			
			image = BitmapFactory.decodeResource(mActivity.getResources(), R.drawable.camera);
			th = new Thread(){
				public void run(){
					node.getBitmapImageThumb();
					mHandler.sendEmptyMessage(0);
				}
			};
			clickListener = getBoxClickListener(PHOTO);
		}
		String dist = "";
		
		if(distance < 1000)
			dist = Float.toString(((float)((int)(distance * 100)))/100) + " m.";
		else
			dist = Float.toString(((float)((int)(distance / 10)))/100) + " Km.";
		
		VistaAR activity = (VistaAR) mActivity;
		int num = activity.getResourcesList().indexOf(this);
		layers.drawSummaryBox(num, title, description, dist, image, clickListener);
		
		if(th != null)
			th.start();
	}
	
	public OnClickListener getBoxClickListener(final int type){
		OnClickListener listener = new OnClickListener() {
			public void onClick(View v) {
				Intent intent;
				switch(type){
				case PHOTO:
					intent = new Intent(mActivity, InfoFoto.class);
					break;
				default:
					return;
				}
				intent.putExtra("node", geoNode);
				mActivity.startActivity(intent);
			}
		};		
		return listener;
	}
}